import unittest

from siquant.units import Unit

class UnitsTestCase(unittest.TestCase):

    def test_base_unit_multiply(self):
        kg = Unit(1, kg=1)
        self.assertEqual(kg * kg * kg, Unit(1, kg=3))

        m = Unit(1, m=1)
        self.assertEqual(kg * m, Unit(1, kg=1, m=1))

        s = Unit(1, s=1)
        self.assertEqual(kg * m * s, Unit(1, kg=1, s=1, m=1))


    def test_base_unit_divide(self):
        unity = Unit(1)
        kg = Unit(1, kg=1)
        m = Unit(1, m=1)
        s = Unit(1, s=1)

        self.assertEqual(kg / kg, unity)
        self.assertEqual(m / m, unity)
        self.assertEqual(s / s, unity)

        self.assertEqual(m / s, Unit(1, m=1, s=-1))

    def test_base_unit_pow(self):
        m = Unit(1, m=1)

        self.assertEqual(m ** 3, Unit(1, m=3))

        s = Unit(1, s=1)

        v = m / s
        self.assertEqual(v ** 2, Unit(1, m=2, s=-2))

    def test_normalize(self):

        m = Unit(1, m=1)
        self.assertEqual(m.normalize(100), 100)

        mm = Unit(1 / 1000, m=1)
        self.assertEqual(mm.normalize(100), 0.1)

        km = Unit(1000, m=1)
        self.assertEqual(km.normalize(100), 100000)

        mm_m = mm * m
        self.assertEqual(mm_m.normalize(100), 0.1)


import unittest

import numpy as np

import siquant.units as u

from siquant import Mass, Distance

class MassTestCase(unittest.TestCase):

    def test_distance(self):

        dist = Distance(1000, u.meters)

        self.assertEqual(dist.get(), 1000)

    def test_mass(self):

        mass = Mass(1000)

        self.assertEqual(mass, Mass(1000, u.kilograms))
        self.assertEqual(mass, Mass(1, u.tonnes))

        self.assertEqual(mass + mass, Mass(2000))
        self.assertEqual(2 * mass, Mass(2000))
        self.assertEqual(mass - mass, Mass(0))
        self.assertEqual(mass / 2, Mass(500))

        self.assertEqual(mass.get_as(u.kilograms), 1000)
        self.assertEqual(mass.get_as(u.tonnes), 1)
        self.assertEqual(mass.get_as(u.grams), 1000000)

        grams = np.array([1000, 2000, 3000])
        masses = Mass(grams, u.grams)

        for (kilos, grams) in zip(masses.get(), grams):
            self.assertEqual(kilos, grams / 1000)



if __name__ == '__main__':
    unittest.main()



from siquant.quantities.qtypes import (
    Distance,
    Area,
    Volume,
    Time,
    Velocity,
    Acceleration,
    Mass,
    Density,
    Force,
    Moment,
    Stress,
    MomentOfArea,
    SectionModulus,
    Angle
)

Distance.q_multiplier(Distance, Area)
Distance.q_multiplier(Area, Volume)
Distance.q_multiplier(Force, Moment)
Distance.q_divider(Time, Velocity)

Area.q_multiplier(Distance, Volume)
Area.q_divider(Distance, Distance)

Volume.q_multiplier(Density, Mass)
Volume.q_divider(Distance, Area)
Volume.q_divider(Area, Distance)

Velocity.q_multiplier(Time, Distance)
Velocity.q_divider(Time, Acceleration)

Force.q_multiplier(Distance, Moment)
Force.q_divider(Area, Stress)
Force.q_divider(Stress, Area)

Mass.q_divider(Volume, Density)
Mass.q_multiplier(Acceleration, Force)

Density.q_multiplier(Volume, Mass)

Moment.q_divider(Distance, Force)
Moment.q_divider(Force, Distance)
Moment.q_divider(SectionModulus, Stress)

Stress.q_multiplier(Area, Force)

MomentOfArea.q_divider(Distance, SectionModulus)

Angle.q_multiplier(Distance, Distance)


from setuptools import setup, find_packages

def readme():
    with open('README.md') as f:
        return f.read()

setup(
    name='siquant',
    version='1.0.0.dev1',
    description='SI units and quantities library',
    long_description=readme(),
    url='https://github.com/keystonetowersystems/siquant',
    author='Greg Echelberger',
    author_email='greg@keystonetowersystems.com',
    packages=find_packages(exclude=('tests',)),
    python_requires='>=3',
    install_requires=[],
    setup_requires=["nose==1.3.7"],
    test_suite="nose.collector",
    zip_safe=True,
    classifiers=[
        "Programming Language :: Python :: 3 :: Only",
        "License :: OSI Approved :: MIT License",
        "Topic :: Scientific/Engineering",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
    ],
)
